import React, {useState} from 'react';
import {Dialog} from "../../../component/dialog/dialog.tsx";
import {ReceivedMessage} from "./types.ts";

interface MessageDialogProps {
    open: boolean;
    message: ReceivedMessage | null;
    onClose: () => void;
}

export const MessageDialog: React.FC<MessageDialogProps> = ({open, message, onClose}) => {
    const [copySuccess, setCopySuccess] = useState(false);

    const handleCopyMessage = () => {
        if (message) {
            navigator.clipboard.writeText(message.text || '').then(() => {
                console.log('消息已复制到剪贴板');
                setCopySuccess(true);
                // 2秒后隐藏成功提示
                setTimeout(() => setCopySuccess(false), 2000);
            }).catch(err => {
                console.error('复制失败:', err);
                alert('复制失败，请手动复制');
            });
        }
    };

    return (
        <Dialog 
            open={open} 
            title="收到新消息" 
            onClose={onClose}
            footer={false}
        >
            <div style={{ marginBottom: '1rem' }}>
                <p style={{ margin: '0 0 0.5rem 0', fontSize: '0.9rem', color: '#666' }}>
                    来自: {message?.sender}
                </p>
                <div style={{ 
                    background: '#f5f5f5', 
                    padding: '1rem', 
                    borderRadius: '4px', 
                    border: '1px solid #ddd',
                    maxHeight: '200px',
                    overflowY: 'auto',
                    whiteSpace: 'pre-wrap',
                    wordBreak: 'break-word'
                }}>
                    {message?.isFile ? (
                        <>
                            <div>📎 文件: {message.fileName} ({message.fileSize ? (message.fileSize/1024).toFixed(1) : ''} KB)</div>
                            <a href={message.fileBlobUrl} download={message.fileName} style={{color:'#007aff',textDecoration:'underline'}}>
                                点击下载
                            </a>
                        </>
                    ) : (
                        message?.text
                    )}
                </div>
            </div>
            <div style={{ display: 'flex', flexDirection: 'row', gap: '0.5rem', justifyContent: 'flex-end', alignItems: 'center', marginTop: '8px' }}>
                {copySuccess && (
                    <span style={{ 
                        color: '#28a745', 
                        fontSize: '0.9rem',
                        marginRight: '0.5rem',
                        animation: 'fadeIn 0.3s ease-in'
                    }}>
                        ✓ 已复制
                    </span>
                )}
                {!message?.isFile && (
                    <button 
                        onClick={handleCopyMessage}
                        style={{
                            padding: '8px 16px',
                            background: copySuccess ? '#28a745' : '#007aff',
                            color: 'white',
                            border: 'none',
                            borderRadius: '4px',
                            cursor: 'pointer',
                            fontSize: '0.9rem',
                            transition: 'all 0.2s'
                        }}
                        onMouseEnter={(e) => {
                            if (!copySuccess) {
                                e.currentTarget.style.backgroundColor = '#0056b3';
                            }
                        }}
                        onMouseLeave={(e) => {
                            if (!copySuccess) {
                                e.currentTarget.style.backgroundColor = '#007aff';
                            }
                        }}
                    >
                        {copySuccess ? '已复制' : '复制消息'}
                    </button>
                )}
                <button
                    onClick={onClose}
                    style={{
                        padding: '8px 16px',
                        background: '#6c757d',
                        color: 'white',
                        border: 'none',
                        borderRadius: '4px',
                        cursor: 'pointer',
                        fontSize: '0.9rem',
                        transition: 'all 0.2s'
                    }}
                >
                    关闭
                </button>
            </div>
        </Dialog>
    );
}; 